aboutsummaryrefslogtreecommitdiff
path: root/guix.scm
diff options
context:
space:
mode:
Diffstat (limited to 'guix.scm')
-rw-r--r--guix.scm6
1 files changed, 4 insertions, 2 deletions
diff --git a/guix.scm b/guix.scm
index 10a7cec..680fe73 100644
--- a/guix.scm
+++ b/guix.scm
@@ -6,10 +6,12 @@
;; We need the actual hydrilla package to be defined in a module so that we can
;; specify it to guix-pack. Hence, the bulk of definitions resides in
;; `hydrilla-guix/hydrilla.scm` and this file is just a thin wrapper around
;; that.
-(add-to-load-path (string-append (dirname (current-filename)) "/hydrilla-guix"))
+(add-to-load-path (string-append
+ (dirname (current-filename))
+ "/guix-module-dir"))
(use-modules (hydrilla))
@@ -6,10 +6,12 @@
;; We need the actual hydrilla package to be defined in a module so that we can
;; specify it to guix-pack. Hence, the bulk of definitions resides in
-;; `hydrilla-guix/hydrilla.scm` and this file is just a thin wrapper around
+;; `guix-module-dir/hydrilla.scm` and this file is just a thin wrapper around
;; that.